library(psych)
library(lme4)
library(lmerTest)
library(plyr)
library(ggplot2)


containStringOfList <- function(substrings,x,include=T, and=F){
  if (!and)
    temp <- rep(F,length(x))
  else
    temp <- rep(T,length(x))
  for (i in substrings)
    if (!and)
      temp <- grepl(i,x,fixed=T) | temp
    else
      temp <- grepl(i,x,fixed=T) & temp
    if (include)
      temp
    else
      !temp
}


scale.0.1 <- function(x){(x-min(x))/(max(x)-min(x))}

load("data_ESM.RData")

#descritpives
table(descriptive["Sex"])
table(descriptive["Age"])
describe(descriptive["Age"])

describe(cubeSing.items.ordered[c("ACC_Item", "RT_Item_log", "Feedback_Item", "Loc_Fixation_num_rel.A", "Entropy_AOI_AB_200", "Levenshtein_MR_AB_200", "z_IPA_diff")])


################################################################################
#models for ACC (logistic)
################################################################################

#2-level-model, one for each level

mlm.results.ACC.logistic <- list()

dep.temp <- "ACC_Item"


for(lev in c("4.1", "3.1", "4.2", "3.2", "4.3", "4.4")){
  dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
  
  mlm.results.ACC.logistic[[lev]] <- list()
  
  #lmer.mod1
  mlm.results.ACC.logistic[[lev]][["lmer.mod1"]] <- list()
  lmer.mod1 <- glmer(dep ~ 1 + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], family = binomial, control = glmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.ACC.logistic[[lev]][["lmer.mod1"]]["model"] <- list(lmer.mod1)
  
  #lmer.mod2a
  mlm.results.ACC.logistic[[lev]][["lmer.mod2a"]] <- list()
  lmer.mod2a <- glmer(dep ~ 1 + z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], family = binomial, control = glmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.ACC.logistic[[lev]][["lmer.mod2a"]]["model"] <- list(lmer.mod2a)
  
  #lmer.mod2b
  mlm.results.ACC.logistic[[lev]][["lmer.mod2b"]] <- list()
  lmer.mod2b <- glmer(dep ~ 1 + z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], family = binomial,  control = glmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.ACC.logistic[[lev]][["lmer.mod2b"]]["model"] <- list(lmer.mod2b)
  
  #lmer.mod3a
  mlm.results.ACC.logistic[[lev]][["lmer.mod3a"]] <- list()
  lmer.mod3a <- glmer(dep ~ rCubeVisACC + z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], family = binomial,  control = glmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.ACC.logistic[[lev]][["lmer.mod3a"]]["model"] <- list(lmer.mod3a)
  
  #lmer.mod3b
  mlm.results.ACC.logistic[[lev]][["lmer.mod3b"]] <- list()
  lmer.mod3b <- glmer(dep ~ rCubeVisACC + z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], family = binomial, control = glmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.ACC.logistic[[lev]][["lmer.mod3b"]]["model"] <- list(lmer.mod3b)
  
  #lmer.mod4a
  mlm.results.ACC.logistic[[lev]][["lmer.mod4a"]] <- list()
  lmer.mod4a <- glmer(dep ~ rCubeVisACC * z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], family = binomial,  control = glmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.ACC.logistic[[lev]][["lmer.mod4a"]]["model"] <- list(lmer.mod4a)
  
  #lmer.mod4b
  mlm.results.ACC.logistic[[lev]][["lmer.mod4b"]] <- list()
  lmer.mod4b <- glmer(dep ~ rCubeVisACC * z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], family = binomial,  control = glmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.ACC.logistic[[lev]][["lmer.mod4b"]]["model"] <- list(lmer.mod4b)
  
}

mlm.results.ACC.logistic.ml <- mlm.results.ACC.logistic
  

#Table
mlm.models <- list(mlm.results.ACC.logistic.ml)
mlm.dep.vars <- c("ACC")
cube.levels <- c("4.1", "3.1", "4.2", "3.2", "4.3", "4.4")

num.models <- 7

tableToWrite <- data.frame(matrix(rep(NA,num.models * 12), ncol = num.models))
colnames(tableToWrite) <- paste("ACC", c("1", "2a", "2b", "3a", "3b","4a", "4b"), sep = "_")
row.names(tableToWrite) <- paste(rep(c("Level_4.1", "Level_3.1", "Level_4.2", "Level_3.2", "Level_4.2.c1", "Level_4.2.c2"),each = 2), rep(c("AIC", "BIC"),1), sep = "_")

mod.nr <- 1

print("-------------------------------------------------")
print(mlm.dep.vars[mod.nr])
mod <- mlm.models[[mod.nr]]
for(lev in c(1:6)){
  print("-------------------------------------------------")
  print(cube.levels[lev])
  print("-------------------------------------------------")
  min.AIC <- Inf
  min.BIC <- Inf
  for(i in c(1:num.models)){
    if(min.AIC > round(AIC(mod[[lev]][[i]]$model),0))
      min.AIC <- round(AIC(mod[[lev]][[i]]$model),0)
    if(min.BIC > round(BIC(mod[[lev]][[i]]$model),0))
      min.BIC <- round(BIC(mod[[lev]][[i]]$model),0)
  }
  
  for(i in c(1:num.models)){
    if(round(AIC(mod[[lev]][[i]]$model),0) == min.AIC)
      tableToWrite[(lev - 1) * 2 + 1, (mod.nr - 1) * num.models  + i] <- paste0(round(AIC(mod[[lev]][[i]]$model),0), "*")
    else
      tableToWrite[(lev - 1) * 2 + 1, (mod.nr - 1) * num.models  + i] <- round(AIC(mod[[lev]][[i]]$model),0)
    
    if(round(BIC(mod[[lev]][[i]]$model),0) == min.BIC)
      tableToWrite[(lev - 1) * 2 + 2, (mod.nr - 1) * num.models  + i] <- paste0(round(BIC(mod[[lev]][[i]]$model),0), "*")
    else
      tableToWrite[(lev - 1) * 2 + 2, (mod.nr - 1) * num.models  + i] <- round(BIC(mod[[lev]][[i]]$model),0)
  }
  
}

write.table(tableToWrite,file="Tables/ModelComparison_ACC_logistic.txt",sep="\t")


################################################################################
#The best models are:
dep.temp = "ACC_Item"
lev = "4.1"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.ACC.logistic.ml$`4.1`$lmer.mod4b$model)

lev = "3.1"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.ACC.logistic.ml$`3.1`$lmer.mod3b$model)

lev = "4.2"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.ACC.logistic.ml$`4.2`$lmer.mod3a$model)

lev = "3.2"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.ACC.logistic.ml$`3.2`$lmer.mod3a$model)

lev = "4.3"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.ACC.logistic.ml$`4.3`$lmer.mod3a$model)

lev = "4.4"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.ACC.logistic.ml$`4.4`$lmer.mod3a$model)



#muiltivariate with all levels is at the end of the script


#Plot
temp.data <- ddply(cubeSing.items.ordered[cubeSing.items.ordered$Level == "4.1",], ~Subject + z_Item_Position + rCubeVisACC, summarize, item_acc = mean(ACC_Item, na.rm = T))

temp.data$z_Item_Position_group <- NA
temp.data[temp.data$z_Item_Position <= .25, "z_Item_Position_group"] <- "1"
temp.data[(temp.data$z_Item_Position > .25) & (temp.data$z_Item_Position <= .50), "z_Item_Position_group"] <- "2"
temp.data[(temp.data$z_Item_Position > .50) & (temp.data$z_Item_Position <= .75), "z_Item_Position_group"] <- "3"
temp.data[temp.data$z_Item_Position > .75, "z_Item_Position_group"] <- "4"

temp.data$z_Item_Position_group <- factor(temp.data$z_Item_Position_group)

pd <- position_dodge(0.5)
size.title <- 1.5
size.numbers <- 1.3
ggplot(temp.data, aes(x = rCubeVisACC, y = item_acc, group = z_Item_Position_group)) +
  geom_smooth(aes(linetype=z_Item_Position_group), colour = "black") +
  xlab("Test performance") + 
  ylab("Item accuracy") +
  scale_linetype_manual( values=c("solid", "twodash", "dotted", "longdash"), guide=guide_legend(title =  "Item\nposition" ), labels = c("< 7", "\u2265 7 & < 13", "\u2265 13 & < 19", "\u2265 19")) +
  theme(axis.text.x=element_text(angle=0, hjust = 1, size = rel(size.numbers)),axis.text.y = element_text(size = rel(size.numbers)), axis.title.x = element_text(size = rel(size.title), face = 'bold'), axis.title.y = element_text(size = rel(size.title), face = 'bold'), legend.title =  element_text(size = rel(size.title), face = 'bold'),legend.text = element_text(size = rel(size.numbers)),legend.key = element_blank(),panel.grid.major=element_blank(), panel.grid.minor = element_blank(), panel.background = element_blank(), axis.line.x = element_line(color = "black"), axis.line.y = element_line(color = "black"))

###################################################################################################################
#models for reaction times
###################################################################################################################




#2-level-model, one for each level

mlm.results.rt <- list()

dep.temp <- "RT_Item_log"

use.reml <- F

for(lev in c("4.1", "3.1", "4.2", "3.2", "4.3", "4.4")){
  dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
  
  mlm.results.rt[[lev]] <- list()
  
  #lmer.mod1
  mlm.results.rt[[lev]][["lmer.mod1"]] <- list()
  lmer.mod1 <- lmer(dep ~ 1 + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.rt[[lev]][["lmer.mod1"]]["model"] <- list(lmer.mod1)
  
  #lmer.mod2a
  mlm.results.rt[[lev]][["lmer.mod2a"]] <- list()
  lmer.mod2a <- lmer(dep ~ 1 + z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.rt[[lev]][["lmer.mod2a"]]["model"] <- list(lmer.mod2a)
  
  #lmer.mod2b
  mlm.results.rt[[lev]][["lmer.mod2b"]] <- list()
  lmer.mod2b <- lmer(dep ~ 1 + z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.rt[[lev]][["lmer.mod2b"]]["model"] <- list(lmer.mod2b)
  
  #lmer.mod3a
  mlm.results.rt[[lev]][["lmer.mod3a"]] <- list()
  lmer.mod3a <- lmer(dep ~ rCubeVisACC + z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))

  mlm.results.rt[[lev]][["lmer.mod3a"]]["model"] <- list(lmer.mod3a)

  #lmer.mod3b
  mlm.results.rt[[lev]][["lmer.mod3b"]] <- list()
  lmer.mod3b <- lmer(dep ~ rCubeVisACC + z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))

  mlm.results.rt[[lev]][["lmer.mod3b"]]["model"] <- list(lmer.mod3b)
  
  #lmer.mod4a
  mlm.results.rt[[lev]][["lmer.mod4a"]] <- list()
  lmer.mod4a <- lmer(dep ~ rCubeVisACC * z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.rt[[lev]][["lmer.mod4a"]]["model"] <- list(lmer.mod4a)
  
  #lmer.mod4b
  mlm.results.rt[[lev]][["lmer.mod4b"]] <- list()
  lmer.mod4b <- lmer(dep ~ rCubeVisACC * z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.rt[[lev]][["lmer.mod4b"]]["model"] <- list(lmer.mod4b)

}

mlm.results.rt_log.ml <- mlm.results.rt


mlm.models <- list(mlm.results.rt_log.ml)
mlm.dep.vars <- c("rt_log")
cube.levels <- c("4.1", "3.1", "4.2", "3.2", "4.3", "4.4")

num.models <- 7

tableToWrite <- data.frame(matrix(rep(NA,12 * num.models), ncol =  num.models))
colnames(tableToWrite) <- paste(rep(c("RT_log"), each = num.models), c("1", "2a", "2b", "3a", "3b","4a", "4b"), sep = "_")
row.names(tableToWrite) <- paste(rep(c("Level_4.1", "Level_3.1", "Level_4.2", "Level_3.2", "Level_4.2.c1", "Level_4.2.c2"),each = 2), rep(c("AIC", "BIC"),1), sep = "_")

mod.nr <- 1
print("-------------------------------------------------")
print(mlm.dep.vars[mod.nr])
mod <- mlm.models[[mod.nr]]
for(lev in c(1:6)){
  print("-------------------------------------------------")
  print(cube.levels[lev])
  print("-------------------------------------------------")
  
  min.AIC <- Inf
  min.BIC <- Inf
  for(i in c(1:num.models)){
    if(min.AIC > round(AIC(mod[[lev]][[i]]$model),0))
      min.AIC <- round(AIC(mod[[lev]][[i]]$model),0)
    if(min.BIC > round(BIC(mod[[lev]][[i]]$model),0))
      min.BIC <- round(BIC(mod[[lev]][[i]]$model),0)
  }
  
  for(i in c(1:num.models)){
    if(round(AIC(mod[[lev]][[i]]$model),0) == min.AIC)
      tableToWrite[(lev - 1) * 2 + 1, (mod.nr - 1) * num.models  + i] <- paste0(round(AIC(mod[[lev]][[i]]$model),0), "*")
    else
      tableToWrite[(lev - 1) * 2 + 1, (mod.nr - 1) * num.models  + i] <- round(AIC(mod[[lev]][[i]]$model),0)
    
    if(round(BIC(mod[[lev]][[i]]$model),0) == min.BIC)
      tableToWrite[(lev - 1) * 2 + 2, (mod.nr - 1) * num.models  + i] <- paste0(round(BIC(mod[[lev]][[i]]$model),0), "*")
    else
      tableToWrite[(lev - 1) * 2 + 2, (mod.nr - 1) * num.models  + i] <- round(BIC(mod[[lev]][[i]]$model),0)
  }
  
}


write.table(tableToWrite,file="Tables/ModelComparison_RT.txt",sep="\t")


################################################################################
#The best models are:
dep.temp = "RT_Item_log"
lev = "4.1"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.rt_log.ml$`4.1`$lmer.mod3b$model)

lev = "3.1"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.rt_log.ml$`3.1`$lmer.mod3b$model)

lev = "4.2"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.rt_log.ml$`4.2`$lmer.mod2b$model)

lev = "3.2"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.rt_log.ml$`3.2`$lmer.mod2b$model)

lev = "4.3"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.rt_log.ml$`4.3`$lmer.mod3b$model)

lev = "4.4"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.rt_log.ml$`4.4`$lmer.mod3b$model)


#muiltivariate with all levels is at the end of the script

#Plot
temp.data <- ddply(cubeSing.items.ordered[cubeSing.items.ordered$Level == "3.2",], ~Subject + z_Item_Position + rCubeVisACC, summarize, rt = mean(RT_Item_log, na.rm = T))

temp.data$z_Item_Position_group <- NA
temp.data[temp.data$z_Item_Position <= .25, "z_Item_Position_group"] <- "1"
temp.data[(temp.data$z_Item_Position > .25) & (temp.data$z_Item_Position <= .50), "z_Item_Position_group"] <- "2"
temp.data[(temp.data$z_Item_Position > .50) & (temp.data$z_Item_Position <= .75), "z_Item_Position_group"] <- "3"
temp.data[temp.data$z_Item_Position > .75, "z_Item_Position_group"] <- "4"

temp.data$z_Item_Position_group <- factor(temp.data$z_Item_Position_group)

pd <- position_dodge(0.5)
size.title <- 1.5
size.numbers <- 1.3
ggplot(temp.data, aes(x = rCubeVisACC, y = rt, group = z_Item_Position_group)) +
  geom_smooth(aes(linetype=z_Item_Position_group), colour = "black") +
  xlab("Test performance") + 
  ylab("Reaction times [log(ms)]") +
  scale_linetype_manual( values=c("solid", "twodash", "dotted", "longdash"), guide=guide_legend(title =  "Item\nposition" ), labels = c("< 7", "\u2265 7 & < 13", "\u2265 13 & < 19", "\u2265 19")) +
  theme(axis.text.x=element_text(angle=0, hjust = 1, size = rel(size.numbers)),axis.text.y = element_text(size = rel(size.numbers)), axis.title.x = element_text(size = rel(size.title), face = 'bold'), axis.title.y = element_text(size = rel(size.title), face = 'bold'), legend.title =  element_text(size = rel(size.title), face = 'bold'),legend.text = element_text(size = rel(size.numbers)),legend.key = element_blank(),panel.grid.major=element_blank(), panel.grid.minor = element_blank(), panel.background = element_blank(), axis.line.x = element_line(color = "black"), axis.line.y = element_line(color = "black"))

###################################################################################################################
#models for Feedback/Confidence Rating
###################################################################################################################


#2-level-model, one for each level

mlm.results.cr <- list()

dep.temp <- "Feedback_Item"

use.reml <- F

for(lev in c("4.1", "3.1", "4.2", "3.2", "4.3", "4.4")){
  dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
  
  mlm.results.cr[[lev]] <- list()
  
  #lmer.mod1
  mlm.results.cr[[lev]][["lmer.mod1"]] <- list()
  lmer.mod1 <- lmer(dep ~ 1 + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.cr[[lev]][["lmer.mod1"]]["model"] <- list(lmer.mod1)
  
  #lmer.mod2a
  mlm.results.cr[[lev]][["lmer.mod2a"]] <- list()
  lmer.mod2a <- lmer(dep ~ 1 + z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.cr[[lev]][["lmer.mod2a"]]["model"] <- list(lmer.mod2a)

  
  #lmer.mod2b
  mlm.results.cr[[lev]][["lmer.mod2b"]] <- list()
  lmer.mod2b <- lmer(dep ~ 1 + z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.cr[[lev]][["lmer.mod2b"]]["model"] <- list(lmer.mod2b)
  
  #lmer.mod3a
  mlm.results.cr[[lev]][["lmer.mod3a"]] <- list()
  lmer.mod3a <- lmer(dep ~ rCubeVisACC + z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))

  mlm.results.cr[[lev]][["lmer.mod3a"]]["model"] <- list(lmer.mod3a)

  #lmer.mod3b
  mlm.results.cr[[lev]][["lmer.mod3b"]] <- list()
  lmer.mod3b <- lmer(dep ~ rCubeVisACC + z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))

  mlm.results.cr[[lev]][["lmer.mod3b"]]["model"] <- list(lmer.mod3b)
  
  
  #lmer.mod4a
  mlm.results.cr[[lev]][["lmer.mod4a"]] <- list()
  lmer.mod4a <- lmer(dep ~ rCubeVisACC * z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.cr[[lev]][["lmer.mod4a"]]["model"] <- list(lmer.mod4a)
  
  #lmer.mod4b
  mlm.results.cr[[lev]][["lmer.mod4b"]] <- list()
  lmer.mod4b <- lmer(dep ~ rCubeVisACC * z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.cr[[lev]][["lmer.mod4b"]]["model"] <- list(lmer.mod4b)
  
}

mlm.results.cr.ml <- mlm.results.cr
  


mlm.models <- list(mlm.results.cr.ml)
mlm.dep.vars <- c("cr")
cube.levels <- c("4.1", "3.1", "4.2", "3.2", "4.3", "4.4")

num.models <- 7

tableToWrite <- data.frame(matrix(rep(NA, num.models * 12), ncol = num.models))
colnames(tableToWrite) <- paste("CR", c("1", "2a", "2b", "3a", "3b","4a", "4b"), sep = "_")
row.names(tableToWrite) <- paste(rep(c("Level_4.1", "Level_3.1", "Level_4.2", "Level_3.2", "Level_4.2.c1", "Level_4.2.c2"),each = 2), rep(c("AIC", "BIC"),1), sep = "_")

mod.nr <- 1

print("-------------------------------------------------")
print(mlm.dep.vars[mod.nr])
mod <- mlm.models[[mod.nr]]
for(lev in c(1:6)){
  print("-------------------------------------------------")
  print(cube.levels[lev])
  print("-------------------------------------------------")
  min.AIC <- Inf
  min.BIC <- Inf
  for(i in c(1:num.models)){
    if(min.AIC > round(AIC(mod[[lev]][[i]]$model),0))
      min.AIC <- round(AIC(mod[[lev]][[i]]$model),0)
    if(min.BIC > round(BIC(mod[[lev]][[i]]$model),0))
      min.BIC <- round(BIC(mod[[lev]][[i]]$model),0)
  }
  
  for(i in c(1:num.models)){
    if(round(AIC(mod[[lev]][[i]]$model),0) == min.AIC)
      tableToWrite[(lev - 1) * 2 + 1, (mod.nr - 1) * num.models  + i] <- paste0(round(AIC(mod[[lev]][[i]]$model),0), "*")
    else
      tableToWrite[(lev - 1) * 2 + 1, (mod.nr - 1) * num.models  + i] <- round(AIC(mod[[lev]][[i]]$model),0)
    
    if(round(BIC(mod[[lev]][[i]]$model),0) == min.BIC)
      tableToWrite[(lev - 1) * 2 + 2, (mod.nr - 1) * num.models  + i] <- paste0(round(BIC(mod[[lev]][[i]]$model),0), "*")
    else
      tableToWrite[(lev - 1) * 2 + 2, (mod.nr - 1) * num.models  + i] <- round(BIC(mod[[lev]][[i]]$model),0)
  }
  
}

write.table(tableToWrite,file="Tables/ModelComparison_CR.txt",sep="\t")


################################################################################
#The best models are:
dep.temp = "Feedback_Item"
lev = "4.1"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.cr.ml$`4.1`$lmer.mod3b$model)

lev = "3.1"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.cr.ml$`3.1`$lmer.mod3b$model)

lev = "4.2"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.cr.ml$`4.2`$lmer.mod3b$model)

lev = "3.2"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.cr.ml$`3.2`$lmer.mod3a$model)

lev = "4.3"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.cr.ml$`4.3`$lmer.mod3b$model)

lev = "4.4"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.cr.ml$`4.4`$lmer.mod2b$model)




#muiltivariate with all levels is at the end of the script

#Plot
temp.data <- ddply(cubeSing.items.ordered[cubeSing.items.ordered$Level == "4.1",], ~z_Item_Position, summarize, feedback = mean(Feedback_Item))

pd <- position_dodge(0.5)
size.title <- 1.5
size.numbers <- 1.3
ggplot(temp.data, aes(x = z_Item_Position, y = feedback)) +
  geom_smooth(colour = "black") +
  xlab("Item position") + 
  ylab("Confidence rating") +
  theme(axis.text.x=element_text(angle=0, hjust = 1, size = rel(size.numbers)),axis.text.y = element_text(size = rel(size.numbers)), axis.title.x = element_text(size = rel(size.title), face = 'bold'), axis.title.y = element_text(size = rel(size.title), face = 'bold'), legend.title =  element_text(size = rel(size.title), face = 'bold'),legend.text = element_text(size = rel(size.numbers)),legend.key = element_blank(),panel.grid.major=element_blank(), panel.grid.minor = element_blank(), panel.background = element_blank(), axis.line.x = element_line(color = "black"), axis.line.y = element_line(color = "black"))


################################################################################
#models for location
################################################################################

mlm.results.loc <- list()

dep.temp <- "Loc_Fixation_num_rel.A"

use.reml <- F

for(lev in c("4.1", "3.1", "4.2", "3.2", "4.3", "4.4")){
  dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
  
  mlm.results.loc[[lev]] <- list()
  
  #lmer.mod1
  mlm.results.loc[[lev]][["lmer.mod1"]] <- list()
  lmer.mod1 <- lmer(dep ~ 1 + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.loc[[lev]][["lmer.mod1"]]["model"] <- list(lmer.mod1)
  mlm.results.loc[[lev]][["lmer.mod1"]]["icc.inter"] <- performance::icc(lmer.mod1)[1]
  
  #lmer.mod2a
  mlm.results.loc[[lev]][["lmer.mod2a"]] <- list()
  lmer.mod2a <- lmer(dep ~ 1 + z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.loc[[lev]][["lmer.mod2a"]]["model"] <- list(lmer.mod2a)
  mlm.results.loc[[lev]][["lmer.mod2a"]]["icc.inter"] <- performance::icc(lmer.mod2a)[1]
  
  #break
  
  #lmer.mod2b
  mlm.results.loc[[lev]][["lmer.mod2b"]] <- list()
  lmer.mod2b <- lmer(dep ~ 1 + z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.loc[[lev]][["lmer.mod2b"]]["model"] <- list(lmer.mod2b)
  
  #lmer.mod3a
  mlm.results.loc[[lev]][["lmer.mod3a"]] <- list()
  lmer.mod3a <- lmer(dep ~ rCubeVisACC + z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.loc[[lev]][["lmer.mod3a"]]["model"] <- list(lmer.mod3a)
  
  #lmer.mod3b
  mlm.results.loc[[lev]][["lmer.mod3b"]] <- list()
  lmer.mod3b <- lmer(dep ~ rCubeVisACC + z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.loc[[lev]][["lmer.mod3b"]]["model"] <- list(lmer.mod3b)
  
  #lmer.mod4a
  mlm.results.loc[[lev]][["lmer.mod4a"]] <- list()
  lmer.mod4a <- lmer(dep ~ rCubeVisACC * z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.loc[[lev]][["lmer.mod4a"]]["model"] <- list(lmer.mod4a)
  
  #lmer.mod4b
  mlm.results.loc[[lev]][["lmer.mod4b"]] <- list()
  lmer.mod4b <- lmer(dep ~ rCubeVisACC * z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.loc[[lev]][["lmer.mod4b"]]["model"] <- list(lmer.mod4b)
  
}

mlm.results.loc.num_rel.A.ml <- mlm.results.loc
  




#Table
mlm.models <- list(mlm.results.loc.num_rel.A.ml)
mlm.dep.vars <- c("A_num_rel")
cube.levels <- c("4.1", "3.1", "4.2", "3.2", "4.3", "4.4")

num.models <- 7

tableToWrite <- data.frame(matrix(rep(NA, num.models * 12), ncol = num.models))
colnames(tableToWrite) <- paste(rep(mlm.dep.vars, each = num.models), c("1", "2a", "2b", "3a", "3b","4a", "4b"), sep = "_")
row.names(tableToWrite) <- paste(rep(c("Level_4.1", "Level_3.1", "Level_4.2", "Level_3.2", "Level_4.2.c1", "Level_4.2.c2"),each = 2), rep(c("AIC", "BIC"),1), sep = "_")

mod.nr <- 1


print("-------------------------------------------------")
print(mlm.dep.vars[mod.nr])
mod <- mlm.models[[mod.nr]]
for(lev in c(1:6)){
  print("-------------------------------------------------")
  print(cube.levels[lev])
  print("-------------------------------------------------")
  min.AIC <- Inf
  min.BIC <- Inf
  for(i in c(1:num.models)){
    if(min.AIC > round(AIC(mod[[lev]][[i]]$model),0))
      min.AIC <- round(AIC(mod[[lev]][[i]]$model),0)
    if(min.BIC > round(BIC(mod[[lev]][[i]]$model),0))
      min.BIC <- round(BIC(mod[[lev]][[i]]$model),0)
  }
  
  for(i in c(1:num.models)){
    if(round(AIC(mod[[lev]][[i]]$model),0) == min.AIC)
      tableToWrite[(lev - 1) * 2 + 1, (mod.nr - 1) * num.models  + i] <- paste0(round(AIC(mod[[lev]][[i]]$model),0), "*")
    else
      tableToWrite[(lev - 1) * 2 + 1, (mod.nr - 1) * num.models  + i] <- round(AIC(mod[[lev]][[i]]$model),0)
    
    if(round(BIC(mod[[lev]][[i]]$model),0) == min.BIC)
      tableToWrite[(lev - 1) * 2 + 2, (mod.nr - 1) * num.models  + i] <- paste0(round(BIC(mod[[lev]][[i]]$model),0), "*")
    else
      tableToWrite[(lev - 1) * 2 + 2, (mod.nr - 1) * num.models  + i] <- round(BIC(mod[[lev]][[i]]$model),0)
  }
  
}

write.table(tableToWrite,file="Tables/ModelComparison_Loc.txt",sep="\t")

################################################################################
#The best models are:
dep.temp = "Loc_Fixation_num_rel.A"
lev = "4.1"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.loc.num_rel.A.ml$`4.1`$lmer.mod2b$model)

lev = "3.1"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.loc.num_rel.A.ml$`3.1`$lmer.mod2b$model)

lev = "4.2"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.loc.num_rel.A.ml$`4.2`$lmer.mod2b$model)

lev = "3.2"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.loc.num_rel.A.ml$`3.2`$lmer.mod2b$model)

lev = "4.3"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.loc.num_rel.A.ml$`4.3`$lmer.mod3b$model)

lev = "4.4"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.loc.num_rel.A.ml$`4.4`$lmer.mod3b$model)


#muiltivariate with all levels is at the end of the script

################################################################################
#models for entropy
################################################################################

mlm.results.entropy <- list()

dep.temp <- "Entropy_AOI_AB_200"

use.reml <- F

for(lev in c("4.1", "3.1", "4.2", "3.2", "4.3", "4.4")){
  dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
  
  mlm.results.entropy[[lev]] <- list()
  
  #lmer.mod1
  mlm.results.entropy[[lev]][["lmer.mod1"]] <- list()
  lmer.mod1 <- lmer(dep ~ 1 + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.entropy[[lev]][["lmer.mod1"]]["model"] <- list(lmer.mod1)
  
  #lmer.mod2a
  mlm.results.entropy[[lev]][["lmer.mod2a"]] <- list()
  lmer.mod2a <- lmer(dep ~ 1 + z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.entropy[[lev]][["lmer.mod2a"]]["model"] <- list(lmer.mod2a)
  
  #lmer.mod2b
  mlm.results.entropy[[lev]][["lmer.mod2b"]] <- list()
  lmer.mod2b <- lmer(dep ~ 1 + z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.entropy[[lev]][["lmer.mod2b"]]["model"] <- list(lmer.mod2b)
  
  #lmer.mod3a
  mlm.results.entropy[[lev]][["lmer.mod3a"]] <- list()
  lmer.mod3a <- lmer(dep ~ rCubeVisACC + z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.entropy[[lev]][["lmer.mod3a"]]["model"] <- list(lmer.mod3a)
  
  #lmer.mod3b
  mlm.results.entropy[[lev]][["lmer.mod3b"]] <- list()
  lmer.mod3b <- lmer(dep ~ rCubeVisACC + z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.entropy[[lev]][["lmer.mod3b"]]["model"] <- list(lmer.mod3b)
  
  #lmer.mod4a
  mlm.results.entropy[[lev]][["lmer.mod4a"]] <- list()
  lmer.mod4a <- lmer(dep ~ rCubeVisACC * z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.entropy[[lev]][["lmer.mod4a"]]["model"] <- list(lmer.mod4a)
  
  #lmer.mod4b
  mlm.results.entropy[[lev]][["lmer.mod4b"]] <- list()
  lmer.mod4b <- lmer(dep ~ rCubeVisACC * z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.entropy[[lev]][["lmer.mod4b"]]["model"] <- list(lmer.mod4b)
  
}

mlm.results.entropy.AB200.ml <- mlm.results.entropy



#Table
mlm.models <- list(mlm.results.entropy.AB200.ml)
mlm.dep.vars <- c("AB_200")
cube.levels <- c("4.1", "3.1", "4.2", "3.2", "4.3", "4.4")

num.models <- 7

tableToWrite <- data.frame(matrix(rep(NA, num.models * 12), ncol = num.models))
colnames(tableToWrite) <- paste(rep(mlm.dep.vars, each = num.models), c("1", "2a", "2b", "3a", "3b","4a", "4b"), sep = "_")
row.names(tableToWrite) <- paste(rep(c("Level_4.1", "Level_3.1", "Level_4.2", "Level_3.2", "Level_4.2.c1", "Level_4.2.c2"),each = 2), rep(c("AIC", "BIC"),1), sep = "_")

mod.nr <- 1

print("-------------------------------------------------")
print(mlm.dep.vars[mod.nr])
mod <- mlm.models[[mod.nr]]
for(lev in c(1:6)){
  print("-------------------------------------------------")
  print(cube.levels[lev])
  print("-------------------------------------------------")
  min.AIC <- Inf
  min.BIC <- Inf
  for(i in c(1:num.models)){
    if(min.AIC > round(AIC(mod[[lev]][[i]]$model),0))
      min.AIC <- round(AIC(mod[[lev]][[i]]$model),0)
    if(min.BIC > round(BIC(mod[[lev]][[i]]$model),0))
      min.BIC <- round(BIC(mod[[lev]][[i]]$model),0)
  }
  
  for(i in c(1:num.models)){
    if(round(AIC(mod[[lev]][[i]]$model),0) == min.AIC)
      tableToWrite[(lev - 1) * 2 + 1, (mod.nr - 1) * num.models  + i] <- paste0(round(AIC(mod[[lev]][[i]]$model),0), "*")
    else
      tableToWrite[(lev - 1) * 2 + 1, (mod.nr - 1) * num.models  + i] <- round(AIC(mod[[lev]][[i]]$model),0)
    
    if(round(BIC(mod[[lev]][[i]]$model),0) == min.BIC)
      tableToWrite[(lev - 1) * 2 + 2, (mod.nr - 1) * num.models  + i] <- paste0(round(BIC(mod[[lev]][[i]]$model),0), "*")
    else
      tableToWrite[(lev - 1) * 2 + 2, (mod.nr - 1) * num.models  + i] <- round(BIC(mod[[lev]][[i]]$model),0)
  }
  
}


write.table(tableToWrite,file="Tables/ModelComparison_Entropy.txt",sep="\t")

################################################################################
#The best models are:
dep.temp = "Entropy_AOI_AB_200"
lev = "4.1"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.entropy.AB200.ml$`4.1`$lmer.mod3b$model)

lev = "3.1"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.entropy.AB200.ml$`3.1`$lmer.mod3b$model)

lev = "4.2"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.entropy.AB200.ml$`4.2`$lmer.mod2b$model)

lev = "3.2"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.entropy.AB200.ml$`3.2`$lmer.mod2b$model)

lev = "4.3"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.entropy.AB200.ml$`4.3`$lmer.mod3b$model)

lev = "4.4"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.entropy.AB200.ml$`4.4`$lmer.mod3b$model)

#muiltivariate with all levels is at the end of the script


################################################################################
#models for levenshtein
################################################################################

mlm.results.levenshtein <- list()

dep.temp <- "Levenshtein_MR_AB_200"

use.reml <- F

for(lev in c("4.1", "3.1", "4.2", "3.2", "4.3", "4.4")){
  dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
  
  mlm.results.levenshtein[[lev]] <- list()
  
  #lmer.mod1
  mlm.results.levenshtein[[lev]][["lmer.mod1"]] <- list()
  lmer.mod1 <- lmer(dep ~ 1 + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.levenshtein[[lev]][["lmer.mod1"]]["model"] <- list(lmer.mod1)
  mlm.results.levenshtein[[lev]][["lmer.mod1"]]["icc.inter"] <- performance::icc(lmer.mod1)[1]
  
  #lmer.mod2a
  mlm.results.levenshtein[[lev]][["lmer.mod2a"]] <- list()
  lmer.mod2a <- lmer(dep ~ 1 + z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.levenshtein[[lev]][["lmer.mod2a"]]["model"] <- list(lmer.mod2a)
  mlm.results.levenshtein[[lev]][["lmer.mod2a"]]["icc.inter"] <- performance::icc(lmer.mod2a)[1]
  
  
  #lmer.mod2b
  mlm.results.levenshtein[[lev]][["lmer.mod2b"]] <- list()
  lmer.mod2b <- lmer(dep ~ 1 + z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.levenshtein[[lev]][["lmer.mod2b"]]["model"] <- list(lmer.mod2b)
  
  #lmer.mod3a
  mlm.results.levenshtein[[lev]][["lmer.mod3a"]] <- list()
  lmer.mod3a <- lmer(dep ~ rCubeVisACC + z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))

  mlm.results.levenshtein[[lev]][["lmer.mod3a"]]["model"] <- list(lmer.mod3a)
  
  #lmer.mod3b
  mlm.results.levenshtein[[lev]][["lmer.mod3b"]] <- list()
  lmer.mod3b <- lmer(dep ~ rCubeVisACC + z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.levenshtein[[lev]][["lmer.mod3b"]]["model"] <- list(lmer.mod3b)
  
  #lmer.mod4a
  mlm.results.levenshtein[[lev]][["lmer.mod4a"]] <- list()
  lmer.mod4a <- lmer(dep ~ rCubeVisACC * z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.levenshtein[[lev]][["lmer.mod4a"]]["model"] <- list(lmer.mod4a)
  
  #lmer.mod4b
  mlm.results.levenshtein[[lev]][["lmer.mod4b"]] <- list()
  lmer.mod4b <- lmer(dep ~ rCubeVisACC * z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.levenshtein[[lev]][["lmer.mod4b"]]["model"] <- list(lmer.mod4b)
  
  
}

mlm.results.levenshtein.AB200.ml <- mlm.results.levenshtein




#Table
mlm.models <- list(mlm.results.levenshtein.AB200.ml)
mlm.dep.vars <- c("AB_200")
cube.levels <- c("4.1", "3.1", "4.2", "3.2", "4.3", "4.4")

num.models <- 7

tableToWrite <- data.frame(matrix(rep(NA, num.models * 12), ncol =  num.models))
colnames(tableToWrite) <- paste(rep(mlm.dep.vars, each = num.models), c("1", "2a", "2b", "3a", "3b","4a", "4b"), sep = "_")
row.names(tableToWrite) <- paste(rep(c("Level_4.1", "Level_3.1", "Level_4.2", "Level_3.2", "Level_4.2.c1", "Level_4.2.c2"),each = 2), rep(c("AIC", "BIC"),1), sep = "_")

mod.nr <- 1


print("-------------------------------------------------")
print(mlm.dep.vars[mod.nr])
mod <- mlm.models[[mod.nr]]
for(lev in c(1:6)){
  print("-------------------------------------------------")
  print(cube.levels[lev])
  print("-------------------------------------------------")
  min.AIC <- Inf
  min.BIC <- Inf
  for(i in c(1:num.models)){
    if(min.AIC > round(AIC(mod[[lev]][[i]]$model),0))
      min.AIC <- round(AIC(mod[[lev]][[i]]$model),0)
    if(min.BIC > round(BIC(mod[[lev]][[i]]$model),0))
      min.BIC <- round(BIC(mod[[lev]][[i]]$model),0)
  }
  
  for(i in c(1:num.models)){
    if(round(AIC(mod[[lev]][[i]]$model),0) == min.AIC)
      tableToWrite[(lev - 1) * 2 + 1, (mod.nr - 1) * num.models  + i] <- paste0(round(AIC(mod[[lev]][[i]]$model),0), "*")
    else
      tableToWrite[(lev - 1) * 2 + 1, (mod.nr - 1) * num.models  + i] <- round(AIC(mod[[lev]][[i]]$model),0)
    
    if(round(BIC(mod[[lev]][[i]]$model),0) == min.BIC)
      tableToWrite[(lev - 1) * 2 + 2, (mod.nr - 1) * num.models  + i] <- paste0(round(BIC(mod[[lev]][[i]]$model),0), "*")
    else
      tableToWrite[(lev - 1) * 2 + 2, (mod.nr - 1) * num.models  + i] <- round(BIC(mod[[lev]][[i]]$model),0)
  }

}


write.table(tableToWrite,file="Tables/ModelComparison_Levenshtein.txt",sep="\t")


################################################################################
#The best models are:
dep.temp = "Levenshtein_MR_AB_200"
lev = "4.1"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.levenshtein.AB200.ml$`4.1`$lmer.mod3b$model)

lev = "3.1"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.levenshtein.AB200.ml$`3.1`$lmer.mod1$model)

lev = "4.2"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.levenshtein.AB200.ml$`4.2`$lmer.mod3b$model)

lev = "3.2"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.levenshtein.AB200.ml$`3.2`$lmer.mod4a$model)

lev = "4.3"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.levenshtein.AB200.ml$`4.3`$lmer.mod3b$model)

lev = "4.4"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.levenshtein.AB200.ml$`4.4`$lmer.mod3b$model)



#muiltivariate with all levels is at the end of the script

#Plot
temp.data <- ddply(cubeSing.items.ordered[cubeSing.items.ordered$Level == "3.2",], ~Subject + z_Item_Position + rCubeVisACC, summarize, levenshtein = mean(Levenshtein_MR_AB_200, na.rm = T))

temp.data$z_Item_Position_group <- NA
temp.data[temp.data$z_Item_Position <= .25, "z_Item_Position_group"] <- "1"
temp.data[(temp.data$z_Item_Position > .25) & (temp.data$z_Item_Position <= .50), "z_Item_Position_group"] <- "2"
temp.data[(temp.data$z_Item_Position > .50) & (temp.data$z_Item_Position <= .75), "z_Item_Position_group"] <- "3"
temp.data[temp.data$z_Item_Position > .75, "z_Item_Position_group"] <- "4"

temp.data$z_Item_Position_group <- factor(temp.data$z_Item_Position_group)

pd <- position_dodge(0.5)
size.title <- 1.5
size.numbers <- 1.3

#group
ggplot(temp.data, aes(x = rCubeVisACC, y = levenshtein, group = z_Item_Position_group)) +
  geom_smooth(aes(linetype = z_Item_Position_group), colour = "black") +
  xlab("Test performance") + 
  ylab("Levenshtein distance ratio") +
  labs(colour = "Item\nposition") +
  scale_linetype_manual( values=c("solid", "twodash", "dotted", "longdash"), guide=guide_legend(title =  "Item\nposition" ), labels = c("< 7", "\u2265 7 & < 13", "\u2265 13 & < 19", "\u2265 19")) +
  theme(axis.text.x=element_text(angle=0, hjust = 1, size = rel(size.numbers)),axis.text.y = element_text(size = rel(size.numbers)), axis.title.x = element_text(size = rel(size.title), face = 'bold'), axis.title.y = element_text(size = rel(size.title), face = 'bold'), legend.title =  element_text(size = rel(size.title), face = 'bold'),legend.text = element_text(size = rel(size.numbers)),legend.key = element_blank(),panel.grid.major=element_blank(), panel.grid.minor = element_blank(), panel.background = element_blank(), axis.line.x = element_line(color = "black"), axis.line.y = element_line(color = "black"))

################################################################################
##IPA
################################################################################

#2-level-model, one for each level


mlm.results.ipa <- list()

dep.temp <- "z_IPA_diff"

use.reml <- F

for(lev in c("4.1", "3.1", "4.2", "3.2", "4.3", "4.4")){
  dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
  
  mlm.results.ipa[[lev]] <- list()
  
  #lmer.mod1
  mlm.results.ipa[[lev]][["lmer.mod1"]] <- list()
  lmer.mod1 <- lmer(dep ~ 1 + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.ipa[[lev]][["lmer.mod1"]]["model"] <- list(lmer.mod1)
  
  #lmer.mod2a
  mlm.results.ipa[[lev]][["lmer.mod2a"]] <- list()
  lmer.mod2a <- lmer(dep ~ 1 + z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.ipa[[lev]][["lmer.mod2a"]]["model"] <- list(lmer.mod2a)
  
  #lmer.mod2b
  mlm.results.ipa[[lev]][["lmer.mod2b"]] <- list()
  lmer.mod2b <- lmer(dep ~ 1 + z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.ipa[[lev]][["lmer.mod2b"]]["model"] <- list(lmer.mod2b)
  
  #lmer.mod3a
  mlm.results.ipa[[lev]][["lmer.mod3a"]] <- list()
  lmer.mod3a <- lmer(dep ~ rCubeVisACC + z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.ipa[[lev]][["lmer.mod3a"]]["model"] <- list(lmer.mod3a)
  
  #lmer.mod3b
  mlm.results.ipa[[lev]][["lmer.mod3b"]] <- list()
  lmer.mod3b <- lmer(dep ~ rCubeVisACC + z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.ipa[[lev]][["lmer.mod3b"]]["model"] <- list(lmer.mod3b)
  
  #lmer.mod4a
  mlm.results.ipa[[lev]][["lmer.mod4a"]] <- list()
  lmer.mod4a <- lmer(dep ~ rCubeVisACC * z_Item_Position + (1 | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.ipa[[lev]][["lmer.mod4a"]]["model"] <- list(lmer.mod4a)
  
  #lmer.mod4b
  mlm.results.ipa[[lev]][["lmer.mod4b"]] <- list()
  lmer.mod4b <- lmer(dep ~ rCubeVisACC * z_Item_Position + (1 + z_Item_Position | Subject_ordered), cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,], REML = use.reml, control = lmerControl(optimizer = "Nelder_Mead"))
  
  mlm.results.ipa[[lev]][["lmer.mod4b"]]["model"] <- list(lmer.mod4b)
  
}

mlm.results.ipa.diff.ml <- mlm.results.ipa



mlm.models <- list(mlm.results.ipa.diff.ml)
mlm.dep.vars <- c("diff")
cube.levels <- c("4.1", "3.1", "4.2", "3.2", "4.3", "4.4")

num.models <- 7

tableToWrite <- data.frame(matrix(rep(NA, num.models * 12), ncol = num.models))
colnames(tableToWrite) <- paste(rep(mlm.dep.vars, each = num.models), c("1", "2a", "2b", "3a", "3b","4a", "4b"), sep = "_")
row.names(tableToWrite) <- paste(rep(c("Level_4.1", "Level_3.1", "Level_4.2", "Level_3.2", "Level_4.2.c1", "Level_4.2.c2"),each = 2), rep(c("AIC", "BIC"),1), sep = "_")

mod.nr <- 1

print("-------------------------------------------------")
print(mlm.dep.vars[mod.nr])
mod <- mlm.models[[mod.nr]]
for(lev in c(1:6)){
  print("-------------------------------------------------")
  print(cube.levels[lev])
  print("-------------------------------------------------")
  min.AIC <- Inf
  min.BIC <- Inf
  for(i in c(1:num.models)){
    if(min.AIC > round(AIC(mod[[lev]][[i]]$model),0))
      min.AIC <- round(AIC(mod[[lev]][[i]]$model),0)
    if(min.BIC > round(BIC(mod[[lev]][[i]]$model),0))
      min.BIC <- round(BIC(mod[[lev]][[i]]$model),0)
  }
  
  for(i in c(1:num.models)){
    if(round(AIC(mod[[lev]][[i]]$model),0) == min.AIC)
      tableToWrite[(lev - 1) * 2 + 1, (mod.nr - 1) * num.models  + i] <- paste0(round(AIC(mod[[lev]][[i]]$model),0), "*")
    else
      tableToWrite[(lev - 1) * 2 + 1, (mod.nr - 1) * num.models  + i] <- round(AIC(mod[[lev]][[i]]$model),0)
    
    if(round(BIC(mod[[lev]][[i]]$model),0) == min.BIC)
      tableToWrite[(lev - 1) * 2 + 2, (mod.nr - 1) * num.models  + i] <- paste0(round(BIC(mod[[lev]][[i]]$model),0), "*")
    else
      tableToWrite[(lev - 1) * 2 + 2, (mod.nr - 1) * num.models  + i] <- round(BIC(mod[[lev]][[i]]$model),0)
  }
  
}

write.table(tableToWrite,file="Tables/ModelComparison_IPA.txt",sep="\t")

################################################################################
#The best models are:

dep.temp = "z_IPA_diff"
lev = "4.1"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.ipa.diff.ml$`4.1`$lmer.mod3a$model)

lev = "3.1"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.ipa.diff.ml$`3.1`$lmer.mod3a$model)

lev = "4.2"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.ipa.diff.ml$`4.2`$lmer.mod1$model)

lev = "3.2"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.ipa.diff.ml$`3.2`$lmer.mod1$model)

lev = "4.3"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.ipa.diff.ml$`4.3`$lmer.mod4a$model)

lev = "4.4"
dep <- cubeSing.items.ordered[cubeSing.items.ordered$Level == lev,dep.temp]
summary(mlm.results.ipa.diff.ml$`4.4`$lmer.mod3a$model)


#muiltivariate with all levels is at the end of the script

#Plot
temp.data <- ddply(cubeSing.items.ordered[cubeSing.items.ordered$Level == "4.3",], ~Subject +z_Item_Position + rCubeVisACC, summarize, IPA = mean(z_IPA_diff, na.rm = T))

temp.data$rCubeVisACC_group <- NA
temp.data[temp.data$rCubeVisACC < .63, "rCubeVisACC_group"] <- "1"
temp.data[(temp.data$rCubeVisACC >= .63) & (temp.data$rCubeVisACC < .75), "rCubeVisACC_group"] <- "2"
temp.data[(temp.data$rCubeVisACC >= .75) & (temp.data$rCubeVisACC < .88), "rCubeVisACC_group"] <- "3"
temp.data[temp.data$rCubeVisACC >= .88, "rCubeVisACC_group"] <- "4"

temp.data$rCubeVisACC_group <- factor(temp.data$rCubeVisACC_group)

pd <- position_dodge(0.5)
size.title <- 1.5
size.numbers <- 1.3

#group
ggplot(temp.data, aes(x = z_Item_Position, y = IPA, group = rCubeVisACC_group)) +
  geom_smooth(method = "loess", aes(linetype = rCubeVisACC_group), colour = "black") +
  xlab("Item position") + 
  ylab("IPA (difference)") +
  labs(colour = "ACC-poss") +
  scale_linetype_manual( values=c("solid", "twodash", "dotted", "longdash"), guide=guide_legend(title =  "Test\nperformance" ), labels = c("< .63", "\u2265 .63 & < 75", "\u2265 75 & < 88", "\u2265 88")) +
  theme(axis.text.x=element_text(angle=0, hjust = 1, size = rel(size.numbers)),axis.text.y = element_text(size = rel(size.numbers)), axis.title.x = element_text(size = rel(size.title), face = 'bold'), axis.title.y = element_text(size = rel(size.title), face = 'bold'), legend.title =  element_text(size = rel(size.title), face = 'bold'),legend.text = element_text(size = rel(size.numbers)),legend.key = element_blank(),panel.grid.major=element_blank(), panel.grid.minor = element_blank(), panel.background = element_blank(), axis.line.x = element_line(color = "black"), axis.line.y = element_line(color = "black"))

################################################################################
#All complete models
##ACC_logistic
lmer.acc_logistic.finalMod <- glmer(ACC_Item ~ 0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44 
                                    + z_Item_Position:Level_41 + z_Item_Position:Level_31 + z_Item_Position:Level_42 + z_Item_Position:Level_32 + z_Item_Position:Level_43 + z_Item_Position:Level_44 
                                    + rCubeVisACC:Level_41 + rCubeVisACC:Level_31 + rCubeVisACC:Level_42 + rCubeVisACC:Level_32 + rCubeVisACC:Level_43 + rCubeVisACC:Level_44
                                    + + z_Item_Position:rCubeVisACC:Level_41       
                                    + (0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44  
                                       + z_Item_Position:Level_41 + z_Item_Position:Level_31 | Subject_ordered),
                                    cubeSing.items.ordered, family = binomial, control = glmerControl(optimizer = "Nelder_Mead"))

lmer.acc_logistic.finalMod_41_3b <- glmer(ACC_Item ~ 0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44 
                                          + z_Item_Position:Level_41 + z_Item_Position:Level_31 + z_Item_Position:Level_42 + z_Item_Position:Level_32 + z_Item_Position:Level_43 + z_Item_Position:Level_44 
                                          + rCubeVisACC:Level_41 + rCubeVisACC:Level_31 + rCubeVisACC:Level_42 + rCubeVisACC:Level_32 + rCubeVisACC:Level_43 + rCubeVisACC:Level_44
                                          + (0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44  
                                             + z_Item_Position:Level_41 + z_Item_Position:Level_31 | Subject_ordered),
                                          cubeSing.items.ordered, family = binomial, control = glmerControl(optimizer = "Nelder_Mead"))

##RT_log
lmer.rt_log.finalMod <- lmer(RT_Item_log ~ 0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44
                             + z_Item_Position:Level_41 + z_Item_Position:Level_31 + z_Item_Position:Level_42 + z_Item_Position:Level_32 + z_Item_Position:Level_43 + z_Item_Position:Level_44
                             + rCubeVisACC:Level_41 + rCubeVisACC:Level_31 + rCubeVisACC:Level_43 + rCubeVisACC:Level_44
                             + (0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44
                                + z_Item_Position:Level_41 + z_Item_Position:Level_31 + z_Item_Position:Level_42 + z_Item_Position:Level_32 + z_Item_Position:Level_43 + z_Item_Position:Level_44| Subject_ordered),
                             cubeSing.items.ordered, REML = F, control = lmerControl(optimizer = "Nelder_Mead"))

##CR
lmer.cr.finalMod <- lmer(Feedback_Item ~ 0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44
                         + z_Item_Position:Level_41 + z_Item_Position:Level_31 + z_Item_Position:Level_42 + z_Item_Position:Level_32 + z_Item_Position:Level_43 + z_Item_Position:Level_44
                         + rCubeVisACC:Level_41 + rCubeVisACC:Level_31 + rCubeVisACC:Level_42 + rCubeVisACC:Level_32 + rCubeVisACC:Level_43
                         + (0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44
                            + z_Item_Position:Level_41 + z_Item_Position:Level_31 + z_Item_Position:Level_42 + z_Item_Position:Level_43 + z_Item_Position:Level_44| Subject_ordered),
                         cubeSing.items.ordered, REML = F, control = lmerControl(optimizer = "Nelder_Mead"))

##Loc
lmer.loc.finalMod <- lmer(Loc_Fixation_num_rel.A ~ 0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44 +
                            z_Item_Position:Level_41 + z_Item_Position:Level_31 + z_Item_Position:Level_42 + z_Item_Position:Level_32 + z_Item_Position:Level_43 + z_Item_Position:Level_44 +
                            rCubeVisACC:Level_43 + rCubeVisACC:Level_44 +
                            (0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44 +
                               z_Item_Position:Level_41 + z_Item_Position:Level_31 + z_Item_Position:Level_42 + z_Item_Position:Level_32 + z_Item_Position:Level_43 + z_Item_Position:Level_44| Subject_ordered),
                          cubeSing.items.ordered, REML = F, control = lmerControl(optimizer = "Nelder_Mead"))



##Entropy
lmer.entropy.finalMod <- lmer(Entropy_AOI_AB_200 ~ 0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44
                              + z_Item_Position:Level_41 + z_Item_Position:Level_31 + z_Item_Position:Level_42 + z_Item_Position:Level_32 + z_Item_Position:Level_43 + z_Item_Position:Level_44
                              + rCubeVisACC:Level_41 + rCubeVisACC:Level_31 + rCubeVisACC:Level_43 + rCubeVisACC:Level_44
                              + (0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44
                                 + z_Item_Position:Level_41 + z_Item_Position:Level_31 + z_Item_Position:Level_42 + z_Item_Position:Level_32 + z_Item_Position:Level_43 + z_Item_Position:Level_44| Subject_ordered),
                              cubeSing.items.ordered, REML = F, control = lmerControl(optimizer = "Nelder_Mead"))


##Levenshtein
lmer.levensthein.finalMod <- lmer(Levenshtein_MR_AB_200 ~ 0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44
                                  + z_Item_Position:Level_41 + z_Item_Position:Level_42 + z_Item_Position:Level_32 + z_Item_Position:Level_43 + z_Item_Position:Level_44
                                  + rCubeVisACC:Level_41 + rCubeVisACC:Level_42 + rCubeVisACC:Level_32 + rCubeVisACC:Level_43 + rCubeVisACC:Level_44
                                  + z_Item_Position:rCubeVisACC:Level_32
                                  + (0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44
                                     + z_Item_Position:Level_41 + z_Item_Position:Level_42 + z_Item_Position:Level_43 + z_Item_Position:Level_44| Subject_ordered),
                                  cubeSing.items.ordered, REML = F, control = lmerControl(optimizer = "Nelder_Mead"))

##IPA_Diff
lmer.ipa_diff.finalMod <- lmer(z_IPA_diff ~ 0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44
                               + z_Item_Position:Level_41 + z_Item_Position:Level_31 + z_Item_Position:Level_43 + z_Item_Position:Level_44
                               + rCubeVisACC:Level_41 + rCubeVisACC:Level_31 + rCubeVisACC:Level_43 + rCubeVisACC:Level_44
                               + z_Item_Position:rCubeVisACC:Level_43
                               + (0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44| Subject_ordered),
                               cubeSing.items.ordered, REML = F, control = lmerControl(optimizer = "Nelder_Mead"))

lmer.ipa_diff.finalMod_Interaction44 <- lmer(z_IPA_diff ~ 0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44
                                             + z_Item_Position:Level_41 + z_Item_Position:Level_31 + z_Item_Position:Level_43 + z_Item_Position:Level_44
                                             + rCubeVisACC:Level_41 + rCubeVisACC:Level_31 + rCubeVisACC:Level_43 + rCubeVisACC:Level_44
                                             + z_Item_Position:rCubeVisACC:Level_43 + z_Item_Position:rCubeVisACC:Level_44
                                             + (0 + Level_41 + Level_31 + Level_42 + Level_32 + Level_43 + Level_44| Subject_ordered),
                                             cubeSing.items.ordered, REML = F, control = lmerControl(optimizer = "Nelder_Mead"))



#save(lmer.rt_log.finalMod, lmer.acc_logistic.finalMod, lmer.acc_logistic.finalMod_41_3b, lmer.cr.finalMod, lmer.ipa_diff.finalMod, lmer.ipa_diff.finalMod_Interaction44, lmer.entropy.finalMod, lmer.loc.finalMod, lmer.levensthein.finalMod, file="Study_LongVersion_RCube_ET_CombinedMLMs.RData")

load(file="Study_LongVersion_RCube_ET_CombinedMLMs.RData")

summary(lmer.acc_logistic.finalMod)
summary(lmer.rt_log.finalMod)
